.. Chalicedoc documentation master file, created by
   sphinx-quickstart on Wed Dec 20 15:19:42 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

.. toctree::
   :maxdepth: 2
   :hidden:

   domain
   example
   Module Docs <chalicedoc>
